@@ -136,6 +136,7 @@ class HttpRunner(object):
 
         for index, testcase in enumerate(test_suite):
             log_handler = None
+            logs_file_abs_path = ""
             if self.save_tests:
                 logs_file_abs_path = utils.prepare_log_file_abs_path(
                     self.test_path, f"testcase_{index+1}.log"
@@ -146,14 +147,16 @@ class HttpRunner(object):
             logger.info(f"Start to run testcase: {testcase_name}")
 
             result = self.unittest_runner.run(testcase)
+
+            if self.save_tests and log_handler:
+                setattr(result, "log_path", logs_file_abs_path)
+                logger.remove(log_handler)
+
             if result.wasSuccessful():
                 tests_results.append((testcase, result))
             else:
                 tests_results.insert(0, (testcase, result))
 
-            if self.save_tests and log_handler:
-                logger.remove(log_handler)
-
         return tests_results
 
     def _aggregate(self, tests_results):
@@ -195,10 +198,7 @@ class HttpRunner(object):
             report.aggregate_stat(summary["time"], testcase_summary["time"])
 
             if self.save_tests:
-                logs_file_abs_path = utils.prepare_log_file_abs_path(
-                    self.test_path, f"testcase_{index+1}.log"
-                )
-                testcase_summary["log"] = logs_file_abs_path
+                testcase_summary["log"] = getattr(result, "log_path")
 
             summary["details"].append(testcase_summary)
 
